
[![PyPI version](https://badge.fury.io/py/pyonear.svg)](https://badge.fury.io/py/pyonear)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/kevinheavey/pyonear/blob/maim/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# near primitives

A wrapper over `py-near-primitives` rust lib for python. Using for [py-near](https://github.com/pvolnov/py-near).

Latest supported version: `py-near-primitives = "0.17.0"`

# use with python 

Use the `py-near` for the high-level api over `py-near-primitives`

Documentation: https://py-near.readthedocs.io/en/latest


## Installation

```
pip install py-near-primitives
```

